locals {
  # Subnets
  subnet_ids = [for v in var.jz_vpc.subnets : v.id]

  # Mapping of ALB listeners from config port_mapping.
  listeners = {
    for i, z in var.port_mapping:
      z.alb_port => {
        app_port   = z.app_port
        app_schema = upper(z.app_schema)
        alb_port   = z.alb_port
        alb_schema = upper(z.alb_schema)
        is_secure  = upper(z.alb_schema) == "HTTPS" || upper(z.alb_schema) == "SSL"
        host       = lookup(z, "host", "")
        order      = lookup(z, "order", null)
      }...
  }

  # Mapping of host-based-routed 443 (HTTPS) records.
  https_with_hosts = {
    for i,z in lookup(local.listeners, "443", []):
    i => {
      app_port = z.app_port
      hosts = flatten(toset([z.host]))
      order = z.order
    }
    if lookup(z, "host", "") != ""
  }

  # Mapping of ALB target groups from config port_mapping.
  target_groups = {
  for i, z in var.port_mapping:
    z.app_port => {
      app_port         = z.app_port
      app_schema       = upper(z.app_schema)
      healthcheck_path = lookup(z, "healthcheck_path", "/")
    }...
  }

  # TGs * instances
  instance_ids_flatten = flatten([
    var.jz_swarm_project.instance_ids.leader,
    var.jz_swarm_project.instance_ids.managers.*]
  )

  instance_ids = var.target_only_managers ? local.instance_ids_flatten : flatten([
    local.instance_ids_flatten,
    var.jz_swarm_project.instance_ids.workers.*]
  )

  target_group_arns = values(aws_lb_target_group.default).*.arn
  tg_x_instance     = flatten([
    for tg in aws_lb_target_group.default: [
      for ins_id in local.instance_ids:
      {
        lb_tg_protocol = tg.protocol
        lb_tg_port     = tg.port
        lb_tg_arn      = tg.arn
        instance_id    = ins_id
      }
    ]
  ])

  # SSL Cert arn
  ssl_cert_arn = var.ssl_cert_arn != null ? var.ssl_cert_arn : data.aws_acm_certificate.default[0].arn
}
